@@ -16,7 +16,7 @@
     <message>
         <location filename="../autostartedit.ui" line="27"/>
         <source>Search...</source>
-        <translation>Suche...</translation>
+        <translation>Suchen...</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="47"/>
@@ -29,7 +29,7 @@
         <translation>Warte auf System Tray</translation>
     </message>
     <message>
-        <location filename="../autostartedit.cpp" line="59"/>
+        <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
         <translation>Anwendung auswählen</translation>
     </message>
@@ -37,22 +37,22 @@
 <context>
     <name>AutoStartItemModel</name>
     <message>
-        <location filename="../autostartmodel.cpp" line="177"/>
+        <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
         <translation>Globaler Autostart</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="179"/>
+        <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
         <translation>LXQt Autostart</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="197"/>
+        <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
         <translation>Ort: %1</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="199"/>
+        <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
         <translation>Überschreibt: %1</translation>
     </message>
@@ -80,12 +80,12 @@
         <translation>Anwendung-Autostart</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Datei &apos;%1&apos; existiert bereits!</translation>
     </message>
@@ -100,7 +100,7 @@
     <message>
         <location filename="../basicsettings.ui" line="30"/>
         <source>Window Manager</source>
-        <translation>Fenstermanager</translation>
+        <translation>Fensterverwaltung</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="49"/>
@@ -110,7 +110,7 @@
     <message>
         <location filename="../basicsettings.ui" line="59"/>
         <source>LXQt Modules</source>
-        <translation>LXQt Module</translation>
+        <translation>LXQt-Module</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="65"/>
@@ -120,33 +120,48 @@
     <message>
         <location filename="../basicsettings.ui" line="72"/>
         <source>Stop</source>
-        <translation>Stopp</translation>
+        <translation>Anhalten</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="84"/>
+        <location filename="../basicsettings.ui" line="124"/>
+        <source>Lock screen before suspending/hibernating</source>
+        <translation>Bildschirm vor dem Wechsel in Bereitschaft/Ruhezustand sperren</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="131"/>
+        <source>Suspend/hibernate after lock delay:</source>
+        <translation>Bereitschaft/Ruhezustand nach einer Sperrverzögerung:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="144"/>
+        <source> ms</source>
+        <translation> ms</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
-        <translation>Fenstermanager auswählen</translation>
+        <translation>Fensterverwaltung auswählen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Leave Session</source>
-        <translation>Sitzung beenden</translation>
+        <translation>Sitzung verlassen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
         <source>Ask for confirmation to leave session</source>
-        <translation>Beenden der Sitzung bestätigen</translation>
+        <translation>Nach Bestätigung zum Verlassen der Sitzung fragen</translation>
     </message>
 </context>
 <context>
     <name>DefaultApps</name>
     <message>
-        <location filename="../defaultappspage.cpp" line="72"/>
+        <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
         <translation>Terminal-Emulator auswählen</translation>
     </message>
     <message>
-        <location filename="../defaultappspage.cpp" line="77"/>
+        <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
         <translation>Web-Browser auswählen</translation>
     </message>
@@ -161,13 +176,13 @@
     <message>
         <location filename="../defaultappspage.ui" line="32"/>
         <source>Terminal Emulation:</source>
-        <translation>Terminal-Emulator:</translation>
+        <translation>Terminal-Emulation:</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="52"/>
         <location filename="../defaultappspage.ui" line="79"/>
         <source>Search...</source>
-        <translation>Suche...</translation>
+        <translation>Suchen...</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="59"/>
@@ -206,7 +221,7 @@
 <context>
     <name>ModuleModel</name>
     <message>
-        <location filename="../modulemodel.cpp" line="85"/>
+        <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
         <translation>Läuft</translation>
     </message>
@@ -214,39 +229,151 @@
 <context>
     <name>SessionConfigWindow</name>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="43"/>
+        <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
-        <translation>LXQt Sitzungseinstellungen</translation>
+        <translation>LXQt-Sitzungseinstellungen</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="46"/>
+        <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
         <translation>Grundeinstellungen</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="52"/>
+        <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
         <translation>Standardanwendungen</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="55"/>
+        <location filename="../sessionconfigwindow.cpp" line="57"/>
+        <source>User Directories</source>
+        <translation>Benutzerverzeichnisse</translation>
+    </message>
+    <message>
+        <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
         <translation>Autostart</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="60"/>
+        <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
         <translation>Umgebung (Erweitert)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="84"/>
+        <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
-        <translation>Erneute Anmeldung erforderlich</translation>
+        <translation>Sitzungsneustart erforderlich</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="85"/>
-        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
-        <translation>Sie müssen sich erneut anmelden (lxqt-session), damit Ihre Änderungen aktiv werden. Klicken Sie dafür auf &quot;Abmelden&quot; im Hauptmenü.</translation>
+        <location filename="../sessionconfigwindow.cpp" line="96"/>
+        <source>Some settings will not take effect until the next log in.</source>
+        <translation>Einige Einstellungen werden erst bei der nächsten Anmeldung wirksam.</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPage</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="116"/>
+        <source>Locations for Personal Files</source>
+        <translation>Speicherorte für persönliche Dateien</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="185"/>
+        <source>LXQt Session Settings - User Directories</source>
+        <translation>LXQt-Sitzungseinstellungen - Benutzerverzeichnisse</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="186"/>
+        <source>An error ocurred while applying the settings for the %1 location</source>
+        <translation>Beim Anwenden der Einstellungen für den Speicherort %1 ist ein Fehler aufgetreten</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="202"/>
+        <source>Choose Location</source>
+        <translation>Speicherort auswählen</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPrivate</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="63"/>
+        <source>Desktop</source>
+        <translation>Schreibtisch</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="64"/>
+        <source>Downloads</source>
+        <translation>Heruntergeladene Dateien</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="65"/>
+        <source>Templates</source>
+        <translation>Vorlagen</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="66"/>
+        <source>Public Share</source>
+        <translation>Öffentlicher Ordner</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="67"/>
+        <source>Documents</source>
+        <translation>Dokumente</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="68"/>
+        <source>Music</source>
+        <translation>Musik</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="69"/>
+        <source>Pictures</source>
+        <translation>Bilder</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="70"/>
+        <source>Videos</source>
+        <translation>Videos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="73"/>
+        <source>Contains all the files which you see on your desktop</source>
+        <translatorcomment>files in template translated with the German word for objects. IMO more reasonable as it&apos;s not necessarily files that are placed on the desktop. Maybe adjust the template accordingly?</translatorcomment>
+        <translation>Enthält alle Dateien, die Sie auf Ihrem Schreibtisch sehen</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="74"/>
+        <source>Default folder to save your downloaded files</source>
+        <translation>Standardordner zum Speichern Ihrer heruntergeladenen Dateien</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="75"/>
+        <source>Default folder to load or save templates from or to</source>
+        <translation>Standardordner zum Laden oder Speichern von Vorlagen</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="76"/>
+        <source>Default folder to publicly share your files</source>
+        <translation>Standardordner für die öffentliche Freigabe Ihrer Dateien</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="77"/>
+        <source>Default folder to load or save documents from or to</source>
+        <translation>Standardordner zum Laden oder Speichern von Dokumenten</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="78"/>
+        <source>Default folder to load or save music from or to</source>
+        <translation>Standardordner zum Laden oder Speichern von Musik</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="79"/>
+        <source>Default folder to load or save pictures from or to</source>
+        <translation>Standardordner zum Laden oder Speichern von Bildern</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="80"/>
+        <source>Default folder to load or save videos from or to</source>
+        <translation>Standardordner zum Laden oder Speichern von Videos</translation>
     </message>
 </context>
 </TS>
