@@ -26,10 +26,10 @@
     <message>
         <location filename="../autostartedit.ui" line="57"/>
         <source>Wait for system tray</source>
-        <translation>Espere al área de notificaciones</translation>
+        <translation>Esperar a la bandeja del sistema</translation>
     </message>
     <message>
-        <location filename="../autostartedit.cpp" line="59"/>
+        <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
         <translation>Seleccionar aplicación</translation>
     </message>
@@ -37,28 +37,24 @@
 <context>
     <name>AutoStartItemModel</name>
     <message>
-        <location filename="../autostartmodel.cpp" line="177"/>
+        <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
         <translation>Autoinicio global</translation>
     </message>
     <message>
-        <source>LxQt Autostart</source>
-        <translation type="vanished">Autoinicio de LxQt</translation>
-    </message>
-    <message>
-        <location filename="../autostartmodel.cpp" line="179"/>
+        <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>Autoinicio de LXQt</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="197"/>
+        <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
-        <translation>Lugar: %1</translation>
+        <translation>Ubicación: %1</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="199"/>
+        <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
-        <translation>Sobreescrito: %1</translation>
+        <translation>Sobrescribe: %1</translation>
     </message>
 </context>
 <context>
@@ -81,17 +77,17 @@
     <message>
         <location filename="../autostartpage.ui" line="44"/>
         <source>Application Autostart</source>
-        <translation>Aplicaciones de inicio automático</translation>
+        <translation>Inicio automático de aplicaciones</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
-        <translation>!Archivo &apos;%1&apos; actualmente existe¡</translation>
+        <translation>¡Ya existe el archivo &apos;%1&apos;!</translation>
     </message>
 </context>
 <context>
@@ -109,27 +105,38 @@
     <message>
         <location filename="../basicsettings.ui" line="59"/>
         <source>LXQt Modules</source>
-        <translation type="unfinished"></translation>
+        <translation>Módulos de LXQt</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Leave Session</source>
-        <translation type="unfinished"></translation>
+        <translation>Cerrar la sesión</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
-        <source>Ask confirmation to leave session</source>
-        <translation type="unfinished"></translation>
+        <source>Ask for confirmation to leave session</source>
+        <translation>Pedir confirmación al cerrar la sesión</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="124"/>
+        <source>Lock screen before suspending/hibernating</source>
+        <translation>Bloquear la pantalla antes de suspender/hibernar</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="131"/>
+        <source>Suspend/hibernate after lock delay:</source>
+        <translation type="unfinished">Retardo para suspender/hibernar tras bloquear:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="144"/>
+        <source> ms</source>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
         <translation>Configuración básica</translation>
     </message>
-    <message>
-        <source>LxQt Modules</source>
-        <translation type="vanished">Módulos de LxQt</translation>
-    </message>
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
@@ -141,7 +148,7 @@
         <translation>Detener</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="84"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
         <translation>Seleccione un gestor de ventanas</translation>
     </message>
@@ -149,12 +156,12 @@
 <context>
     <name>DefaultApps</name>
     <message>
-        <location filename="../defaultappspage.cpp" line="72"/>
+        <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
         <translation>Seleccione un emulador de terminal</translation>
     </message>
     <message>
-        <location filename="../defaultappspage.cpp" line="77"/>
+        <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
         <translation>Seleccione un navegador web</translation>
     </message>
@@ -186,27 +193,27 @@
 <context>
     <name>EnvironmentPage</name>
     <message>
-        <location filename="../environmentpage.ui" line="30"/>
+        <location filename="../environmentpage.ui" line="17"/>
         <source>Add</source>
         <translation>Añadir</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="37"/>
+        <location filename="../environmentpage.ui" line="24"/>
         <source>Delete</source>
         <translation>Eliminar</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="63"/>
+        <location filename="../environmentpage.ui" line="50"/>
         <source>Environment Variables (Advanced)</source>
         <translation>Variables de entorno (avanzado)</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="74"/>
+        <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
         <translation>Nombre de la variable</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="79"/>
+        <location filename="../environmentpage.ui" line="66"/>
         <source>Value</source>
         <translation>Valor</translation>
     </message>
@@ -214,51 +221,158 @@
 <context>
     <name>ModuleModel</name>
     <message>
-        <location filename="../modulemodel.cpp" line="85"/>
+        <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
-        <translation>Ejecutandose</translation>
+        <translation>Ejecutándose</translation>
     </message>
 </context>
 <context>
     <name>SessionConfigWindow</name>
     <message>
-        <source>LxQt Session Configuration</source>
-        <translation type="vanished">Configuración de la sesión de LxQt</translation>
-    </message>
-    <message>
-        <location filename="../sessionconfigwindow.cpp" line="43"/>
+        <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuración de la sesión de LXQt</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="46"/>
+        <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
         <translation>Configuración básica</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="52"/>
+        <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
         <translation>Aplicaciones predeterminadas</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="55"/>
+        <location filename="../sessionconfigwindow.cpp" line="57"/>
+        <source>User Directories</source>
+        <translation>Directorios de usuario</translation>
+    </message>
+    <message>
+        <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
         <translation>Inicio automático</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="60"/>
+        <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
         <translation>Entorno (avanzado)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="84"/>
+        <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
         <translation>Se requiere un reinicio de sesión</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="85"/>
-        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
-        <translation>Necesita reiniciar la sesión de escritorio (lxqt-session) para recargar la configuración. Cierre la sesión desde el menú principal.</translation>
+        <location filename="../sessionconfigwindow.cpp" line="96"/>
+        <source>Some settings will not take effect until the next log in.</source>
+        <translation>Algunos ajustes no tendrán efecto hasta el siguiente inicio de sesión.</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPage</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="116"/>
+        <source>Locations for Personal Files</source>
+        <translation>Ubicaciones para los archivos personales</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="185"/>
+        <source>LXQt Session Settings - User Directories</source>
+        <translation>Configuración de la sesión de LXQt - Directorios de usuario</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="186"/>
+        <source>An error ocurred while applying the settings for the %1 location</source>
+        <translation>Ha ocurrido un error al aplicar la configuración para la ubicación %1</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="202"/>
+        <source>Choose Location</source>
+        <translation>Elija una ubicación</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPrivate</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="63"/>
+        <source>Desktop</source>
+        <translation>Escritorio</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="64"/>
+        <source>Downloads</source>
+        <translation>Descargas</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="65"/>
+        <source>Templates</source>
+        <translation>Plantillas</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="66"/>
+        <source>Public Share</source>
+        <translation>Público</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="67"/>
+        <source>Documents</source>
+        <translation>Documentos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="68"/>
+        <source>Music</source>
+        <translation>Música</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="69"/>
+        <source>Pictures</source>
+        <translation>Imágenes</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="70"/>
+        <source>Videos</source>
+        <translation>Vídeos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="73"/>
+        <source>Contains all the files which you see on your desktop</source>
+        <translation>Contiene todos los archivos que ve en el escritorio</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="74"/>
+        <source>Default folder to save your downloaded files</source>
+        <translation>Carpeta por omisión donde descargar archivos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="75"/>
+        <source>Default folder to load or save templates from or to</source>
+        <translation>Carpeta por omisión desde donde cargar o donde guardar plantillas</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="76"/>
+        <source>Default folder to publicly share your files</source>
+        <translation>Carpeta por omisión para compartir públicamente archivos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="77"/>
+        <source>Default folder to load or save documents from or to</source>
+        <translation>Carpeta por omisión donde guardar o desde donde cargar documentos</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="78"/>
+        <source>Default folder to load or save music from or to</source>
+        <translation>Carpeta por defecto desde donde cargar o donde guardar música</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="79"/>
+        <source>Default folder to load or save pictures from or to</source>
+        <translation>Carpeta por omisión desde donde cargar o donde guardar imágenes</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="80"/>
+        <source>Default folder to load or save videos from or to</source>
+        <translation>Carpeta por omisión desde donde cargar o donde guardar vídeos</translation>
     </message>
 </context>
 </TS>
