@@ -29,7 +29,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../autostartedit.cpp" line="59"/>
+        <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
         <translation>Valitse sovellus</translation>
     </message>
@@ -37,26 +37,22 @@
 <context>
     <name>AutoStartItemModel</name>
     <message>
-        <location filename="../autostartmodel.cpp" line="177"/>
+        <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
         <translation>Yleinen automaattikäynnistys</translation>
     </message>
     <message>
-        <source>LxQt Autostart</source>
-        <translation type="vanished">LxQtin automaattikäynnistys</translation>
-    </message>
-    <message>
-        <location filename="../autostartmodel.cpp" line="179"/>
+        <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQtin automaattikäynnistys</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="197"/>
+        <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
         <translation>Sijainti: %1</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="199"/>
+        <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -84,12 +80,12 @@
         <translation>Sovellusten automaattikäynnistys</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Tiedosto &quot;%1&quot; on jo olemassa!</translation>
     </message>
@@ -109,16 +105,31 @@
     <message>
         <location filename="../basicsettings.ui" line="59"/>
         <source>LXQt Modules</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">LXQt-moduulit</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Leave Session</source>
-        <translation type="unfinished"></translation>
+        <translation>Istunnon lopettaminen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
-        <source>Ask confirmation to leave session</source>
+        <source>Ask for confirmation to leave session</source>
+        <translation>Pyydä vahvistusta istunnon lopettamiseen</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="124"/>
+        <source>Lock screen before suspending/hibernating</source>
+        <translation>Lukitse näyttö ennen valmius- tai lepotilaan siirtymistä</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="131"/>
+        <source>Suspend/hibernate after lock delay:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="144"/>
+        <source> ms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -126,10 +137,6 @@
         <source>Basic Settings</source>
         <translation>Perusasetukset</translation>
     </message>
-    <message>
-        <source>LxQt Modules</source>
-        <translation type="vanished">LxQt-moduulit</translation>
-    </message>
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
@@ -141,7 +148,7 @@
         <translation>Pysäytä</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="84"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
         <translation>Valitse ikkunahallinta</translation>
     </message>
@@ -149,12 +156,12 @@
 <context>
     <name>DefaultApps</name>
     <message>
-        <location filename="../defaultappspage.cpp" line="72"/>
+        <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
         <translation>Valitse pääte</translation>
     </message>
     <message>
-        <location filename="../defaultappspage.cpp" line="77"/>
+        <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
         <translation>Valitse nettiselain</translation>
     </message>
@@ -186,27 +193,27 @@
 <context>
     <name>EnvironmentPage</name>
     <message>
-        <location filename="../environmentpage.ui" line="30"/>
+        <location filename="../environmentpage.ui" line="17"/>
         <source>Add</source>
         <translation>Lisää</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="37"/>
+        <location filename="../environmentpage.ui" line="24"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="63"/>
+        <location filename="../environmentpage.ui" line="50"/>
         <source>Environment Variables (Advanced)</source>
         <translation>Ympäristömuuttujat (lisäasetukset)</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="74"/>
+        <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
         <translation>Muuttujan nimi</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="79"/>
+        <location filename="../environmentpage.ui" line="66"/>
         <source>Value</source>
         <translation>Arvo</translation>
     </message>
@@ -214,7 +221,7 @@
 <context>
     <name>ModuleModel</name>
     <message>
-        <location filename="../modulemodel.cpp" line="85"/>
+        <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
         <translation>Käynnissä</translation>
     </message>
@@ -222,43 +229,150 @@
 <context>
     <name>SessionConfigWindow</name>
     <message>
-        <source>LxQt Session Configuration</source>
-        <translation type="vanished">LxQtin istuntohallinta</translation>
-    </message>
-    <message>
-        <location filename="../sessionconfigwindow.cpp" line="43"/>
+        <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt-istunnon asetukset</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="46"/>
+        <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
         <translation>Perusasetukset</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="52"/>
+        <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
         <translation>Oletussovellukset</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="55"/>
+        <location filename="../sessionconfigwindow.cpp" line="57"/>
+        <source>User Directories</source>
+        <translation>Käyttäjien hakemistot</translation>
+    </message>
+    <message>
+        <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
         <translation>Automaattikäynnistys</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="60"/>
+        <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
         <translation>Ympäristö (lisäasetukset)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="84"/>
+        <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
         <translation>Istunnon uudelleenkäynnistys vaaditaan</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="85"/>
-        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
-        <translation>Asetusten voimaantulo vaatii työpöytäistunnon (lxqt-session) uudelleenkäynnistyksen. Kirjaudu ulos päävalikkoa käyttäen.</translation>
+        <location filename="../sessionconfigwindow.cpp" line="96"/>
+        <source>Some settings will not take effect until the next log in.</source>
+        <translation>Osa asetuksista ei tule voimaan ennen seuraavaa sisäänkirjaumista.</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPage</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="116"/>
+        <source>Locations for Personal Files</source>
+        <translation>Henkilökohtaisten tiedostojen sijainnit</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="185"/>
+        <source>LXQt Session Settings - User Directories</source>
+        <translation type="unfinished">LXQt-istunnon asetukset - Käyttäjien hakemistot</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="186"/>
+        <source>An error ocurred while applying the settings for the %1 location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="202"/>
+        <source>Choose Location</source>
+        <translation>Valitse sijainti</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPrivate</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="63"/>
+        <source>Desktop</source>
+        <translation>Työpöytä</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="64"/>
+        <source>Downloads</source>
+        <translation>Lataukset</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="65"/>
+        <source>Templates</source>
+        <translation>Mallit</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="66"/>
+        <source>Public Share</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="67"/>
+        <source>Documents</source>
+        <translation>Asiakirjat</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="68"/>
+        <source>Music</source>
+        <translation>Musiikki</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="69"/>
+        <source>Pictures</source>
+        <translation>Kuvat</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="70"/>
+        <source>Videos</source>
+        <translation>Videot</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="73"/>
+        <source>Contains all the files which you see on your desktop</source>
+        <translation>Sisältää kaikki tiedostot, jotka näkyvät työpöydällä</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="74"/>
+        <source>Default folder to save your downloaded files</source>
+        <translation>Oletuskansio johon ladatut tiedostot tallennetaan</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="75"/>
+        <source>Default folder to load or save templates from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="76"/>
+        <source>Default folder to publicly share your files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="77"/>
+        <source>Default folder to load or save documents from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="78"/>
+        <source>Default folder to load or save music from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="79"/>
+        <source>Default folder to load or save pictures from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="80"/>
+        <source>Default folder to load or save videos from or to</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
