@@ -29,7 +29,7 @@
         <translation>Attendi il vassoio di sistema</translation>
     </message>
     <message>
-        <location filename="../autostartedit.cpp" line="59"/>
+        <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
         <translation>Seleziona applicazione</translation>
     </message>
@@ -37,26 +37,22 @@
 <context>
     <name>AutoStartItemModel</name>
     <message>
-        <location filename="../autostartmodel.cpp" line="177"/>
+        <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
         <translation>Avvio automatico globale</translation>
     </message>
     <message>
-        <source>LxQt Autostart</source>
-        <translation type="vanished">Avvio automatico di LxQt</translation>
-    </message>
-    <message>
-        <location filename="../autostartmodel.cpp" line="179"/>
+        <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation></translation>
+        <translation>Avvio automatico di LXQt</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="197"/>
+        <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
         <translation>Posizione: %1</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="199"/>
+        <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
         <translation>Sostituisce: %1</translation>
     </message>
@@ -66,7 +62,7 @@
     <message>
         <location filename="../autostartpage.ui" line="17"/>
         <source>Delete</source>
-        <translation>Cancella</translation>
+        <translation>Elimina</translation>
     </message>
     <message>
         <location filename="../autostartpage.ui" line="24"/>
@@ -84,12 +80,12 @@
         <translation>Avvio automatico delle applicazioni</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="82"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Il file &apos;%1&apos; esiste già!</translation>
     </message>
@@ -118,18 +114,29 @@
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
-        <source>Ask confirmation to leave session</source>
+        <source>Ask for confirmation to leave session</source>
         <translation>Chiedi una conferma per terminare la sessione</translation>
     </message>
+    <message>
+        <location filename="../basicsettings.ui" line="124"/>
+        <source>Lock screen before suspending/hibernating</source>
+        <translation>Blocca lo schermo prima di sospendere o ibernare</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="131"/>
+        <source>Suspend/hibernate after lock delay:</source>
+        <translation>Sospendi/iberna dopo il blocco:</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="144"/>
+        <source> ms</source>
+        <translation> ms</translation>
+    </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
         <translation>Impostazioni di base</translation>
     </message>
-    <message>
-        <source>LxQt Modules</source>
-        <translation type="vanished">Moduli di LxQt</translation>
-    </message>
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
@@ -141,7 +148,7 @@
         <translation>Ferma</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="84"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
         <translation>Seleziona un gestore delle finestre</translation>
     </message>
@@ -149,12 +156,12 @@
 <context>
     <name>DefaultApps</name>
     <message>
-        <location filename="../defaultappspage.cpp" line="72"/>
+        <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
         <translation>Seleziona un emulatore di terminale</translation>
     </message>
     <message>
-        <location filename="../defaultappspage.cpp" line="77"/>
+        <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
         <translation>Seleziona un browser web</translation>
     </message>
@@ -169,7 +176,7 @@
     <message>
         <location filename="../defaultappspage.ui" line="32"/>
         <source>Terminal Emulation:</source>
-        <translation>Emulatore di terminale:</translation>
+        <translation>Emulazione di terminale:</translation>
     </message>
     <message>
         <location filename="../defaultappspage.ui" line="52"/>
@@ -186,27 +193,27 @@
 <context>
     <name>EnvironmentPage</name>
     <message>
-        <location filename="../environmentpage.ui" line="30"/>
+        <location filename="../environmentpage.ui" line="17"/>
         <source>Add</source>
         <translation>Aggiungi</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="37"/>
+        <location filename="../environmentpage.ui" line="24"/>
         <source>Delete</source>
-        <translation>Cancella</translation>
+        <translation>Elimina</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="63"/>
+        <location filename="../environmentpage.ui" line="50"/>
         <source>Environment Variables (Advanced)</source>
-        <translation>Variabili dell&apos;ambiente (avanzato)</translation>
+        <translation>Variabili d&apos;ambiente (avanzato)</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="74"/>
+        <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
         <translation>Nome variabile</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="79"/>
+        <location filename="../environmentpage.ui" line="66"/>
         <source>Value</source>
         <translation>Valore</translation>
     </message>
@@ -214,7 +221,7 @@
 <context>
     <name>ModuleModel</name>
     <message>
-        <location filename="../modulemodel.cpp" line="85"/>
+        <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
         <translation>In esecuzione</translation>
     </message>
@@ -222,43 +229,150 @@
 <context>
     <name>SessionConfigWindow</name>
     <message>
-        <source>LxQt Session Configuration</source>
-        <translation type="vanished">Configurazione della sessione di LxQt</translation>
-    </message>
-    <message>
-        <location filename="../sessionconfigwindow.cpp" line="43"/>
+        <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
         <translation>Impostazioni della sessione LXQt</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="46"/>
+        <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
         <translation>Impostazioni di base</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="52"/>
+        <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
         <translation>Applicazioni predefinite</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="55"/>
+        <location filename="../sessionconfigwindow.cpp" line="57"/>
+        <source>User Directories</source>
+        <translation>Percorsi</translation>
+    </message>
+    <message>
+        <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
         <translation>Avvio automatico</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="60"/>
+        <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
         <translation>Ambiente (avanzato)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="84"/>
+        <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
-        <translation>Necessario riavvio della sessione</translation>
+        <translation>Riavvio della sessione richiesto</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="85"/>
-        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
-        <translation>Devi riavviare la sessione desktop (lxqt-session) per ricaricare le impostazioni. Termina la sessione tramite il menu principale.</translation>
+        <location filename="../sessionconfigwindow.cpp" line="96"/>
+        <source>Some settings will not take effect until the next log in.</source>
+        <translation>Alcune impostazioni non avranno effetto fino al prossimo accesso.</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPage</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="116"/>
+        <source>Locations for Personal Files</source>
+        <translation>Posizioni per i file personali</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="185"/>
+        <source>LXQt Session Settings - User Directories</source>
+        <translation>Impostazioni della sessione LXQt - Percorsi</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="186"/>
+        <source>An error ocurred while applying the settings for the %1 location</source>
+        <translation>Si è verificato un errore durante l&apos;applicazione delle impostazioni per la posizione %1</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="202"/>
+        <source>Choose Location</source>
+        <translation>Scegli posizione</translation>
+    </message>
+</context>
+<context>
+    <name>UserLocationsPrivate</name>
+    <message>
+        <location filename="../userlocationspage.cpp" line="63"/>
+        <source>Desktop</source>
+        <translation>Scrivania</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="64"/>
+        <source>Downloads</source>
+        <translation>Scaricamenti</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="65"/>
+        <source>Templates</source>
+        <translation>Modelli</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="66"/>
+        <source>Public Share</source>
+        <translation>Condivisione pubblica</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="67"/>
+        <source>Documents</source>
+        <translation>Documenti</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="68"/>
+        <source>Music</source>
+        <translation>Musica</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="69"/>
+        <source>Pictures</source>
+        <translation>Immagini</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="70"/>
+        <source>Videos</source>
+        <translation>Video</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="73"/>
+        <source>Contains all the files which you see on your desktop</source>
+        <translation>Contiene tutti i file presenti sulla scrivania</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="74"/>
+        <source>Default folder to save your downloaded files</source>
+        <translation>Percorso predefinito per salvare i file scaricati</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="75"/>
+        <source>Default folder to load or save templates from or to</source>
+        <translation>Percorso predefinito per salvare e caricare i modelli</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="76"/>
+        <source>Default folder to publicly share your files</source>
+        <translation>Percorso predefinito per i file condivisi</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="77"/>
+        <source>Default folder to load or save documents from or to</source>
+        <translation>Percorso predefinito per salvare e caricare i documenti</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="78"/>
+        <source>Default folder to load or save music from or to</source>
+        <translation>Cartella predefinita per caricare o salvare musica</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="79"/>
+        <source>Default folder to load or save pictures from or to</source>
+        <translation>Percorso predefinito per salvare e caricare i file immagini</translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="80"/>
+        <source>Default folder to load or save videos from or to</source>
+        <translation>Percorso predefinito per salvare e caricare i video</translation>
     </message>
 </context>
 </TS>
