@@ -29,7 +29,7 @@
         <translation>Počakaj na sistemsko vrstico</translation>
     </message>
     <message>
-        <location filename="../autostartedit.cpp" line="59"/>
+        <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
         <translation>Izberite program</translation>
     </message>
@@ -37,22 +37,22 @@
 <context>
     <name>AutoStartItemModel</name>
     <message>
-        <location filename="../autostartmodel.cpp" line="192"/>
+        <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
         <translation>Globalni samodejni zagon</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="194"/>
+        <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
         <translation>Samodejni zagon za lxqt</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="212"/>
+        <location filename="../autostartmodel.cpp" line="213"/>
         <source>Location: %1</source>
         <translation>Lokacija: %1</translation>
     </message>
     <message>
-        <location filename="../autostartmodel.cpp" line="214"/>
+        <location filename="../autostartmodel.cpp" line="215"/>
         <source>Overrides: %1</source>
         <translation>Povozi: %1</translation>
     </message>
@@ -80,12 +80,12 @@
         <translation>Samodejni zagon programa</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="141"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
         <translation>Napaka</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="141"/>
+        <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Datoteka »%1« že obstaja.</translation>
     </message>
@@ -117,6 +117,21 @@
         <source>Ask for confirmation to leave session</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../basicsettings.ui" line="124"/>
+        <source>Lock screen before suspending/hibernating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="131"/>
+        <source>Suspend/hibernate after lock delay:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.ui" line="144"/>
+        <source> ms</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
@@ -133,7 +148,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="137"/>
+        <location filename="../basicsettings.cpp" line="156"/>
         <source>Select a window manager</source>
         <translation>Izberite upravljalnika oken</translation>
     </message>
@@ -141,12 +156,12 @@
 <context>
     <name>DefaultApps</name>
     <message>
-        <location filename="../defaultappspage.cpp" line="72"/>
+        <location filename="../defaultappspage.cpp" line="74"/>
         <source>Select a terminal emulator</source>
         <translation>Izberite posnemovalnika terminala</translation>
     </message>
     <message>
-        <location filename="../defaultappspage.cpp" line="77"/>
+        <location filename="../defaultappspage.cpp" line="79"/>
         <source>Select a web browser</source>
         <translation>Izberite spletni brskalnik</translation>
     </message>
@@ -206,7 +221,7 @@
 <context>
     <name>ModuleModel</name>
     <message>
-        <location filename="../modulemodel.cpp" line="86"/>
+        <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
         <translation type="unfinished"></translation>
     </message>
@@ -214,73 +229,65 @@
 <context>
     <name>SessionConfigWindow</name>
     <message>
-        <source>LXQt Session Configuration</source>
-        <translation type="vanished">Nastavitve seje LXQt</translation>
-    </message>
-    <message>
-        <location filename="../sessionconfigwindow.cpp" line="44"/>
+        <location filename="../sessionconfigwindow.cpp" line="45"/>
         <source>LXQt Session Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="47"/>
+        <location filename="../sessionconfigwindow.cpp" line="48"/>
         <source>Basic Settings</source>
         <translation>Osnovne nastavitve</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="53"/>
+        <location filename="../sessionconfigwindow.cpp" line="54"/>
         <source>Default Applications</source>
         <translation>Privzeti programi</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="56"/>
-        <source>Locations</source>
+        <location filename="../sessionconfigwindow.cpp" line="57"/>
+        <source>User Directories</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="62"/>
+        <location filename="../sessionconfigwindow.cpp" line="63"/>
         <source>Autostart</source>
         <translation>Samodejni zagon</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="68"/>
+        <location filename="../sessionconfigwindow.cpp" line="69"/>
         <source>Environment (Advanced)</source>
         <translation>Okolje (napredno)</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="92"/>
+        <location filename="../sessionconfigwindow.cpp" line="95"/>
         <source>Session Restart Required</source>
         <translation>Potreben je ponoven zagon seje</translation>
     </message>
     <message>
-        <location filename="../sessionconfigwindow.cpp" line="93"/>
+        <location filename="../sessionconfigwindow.cpp" line="96"/>
         <source>Some settings will not take effect until the next log in.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
-        <translation type="vanished">Za ponovno naložitev nastavitev morate znova zagnati sejo namizja (lxqt-session). Iz glavnega menija izberite Odjavi.</translation>
-    </message>
 </context>
 <context>
     <name>UserLocationsPage</name>
     <message>
-        <location filename="../userlocationspage.cpp" line="99"/>
+        <location filename="../userlocationspage.cpp" line="116"/>
         <source>Locations for Personal Files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="160"/>
-        <source>LXQt Session Settings - Locations</source>
+        <location filename="../userlocationspage.cpp" line="185"/>
+        <source>LXQt Session Settings - User Directories</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="161"/>
+        <location filename="../userlocationspage.cpp" line="186"/>
         <source>An error ocurred while applying the settings for the %1 location</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="177"/>
+        <location filename="../userlocationspage.cpp" line="202"/>
         <source>Choose Location</source>
         <translation type="unfinished"></translation>
     </message>
@@ -288,44 +295,84 @@
 <context>
     <name>UserLocationsPrivate</name>
     <message>
-        <location filename="../userlocationspage.cpp" line="59"/>
+        <location filename="../userlocationspage.cpp" line="63"/>
         <source>Desktop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="60"/>
+        <location filename="../userlocationspage.cpp" line="64"/>
         <source>Downloads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="61"/>
+        <location filename="../userlocationspage.cpp" line="65"/>
         <source>Templates</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="62"/>
+        <location filename="../userlocationspage.cpp" line="66"/>
         <source>Public Share</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="63"/>
+        <location filename="../userlocationspage.cpp" line="67"/>
         <source>Documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="64"/>
+        <location filename="../userlocationspage.cpp" line="68"/>
         <source>Music</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="65"/>
+        <location filename="../userlocationspage.cpp" line="69"/>
         <source>Pictures</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../userlocationspage.cpp" line="66"/>
+        <location filename="../userlocationspage.cpp" line="70"/>
         <source>Videos</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="73"/>
+        <source>Contains all the files which you see on your desktop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="74"/>
+        <source>Default folder to save your downloaded files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="75"/>
+        <source>Default folder to load or save templates from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="76"/>
+        <source>Default folder to publicly share your files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="77"/>
+        <source>Default folder to load or save documents from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="78"/>
+        <source>Default folder to load or save music from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="79"/>
+        <source>Default folder to load or save pictures from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../userlocationspage.cpp" line="80"/>
+        <source>Default folder to load or save videos from or to</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
