@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LxQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org, http://lxde.org/
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https:///lxqt.org/
  *
  * Copyright: 2010-2015 LXQt team
  * Authors:
@@ -31,7 +31,9 @@
 #include "ui_leavedialog.h"
 
 #include <QDialog>
+#include <QDesktopWidget>
 #include <LXQt/Power>
+#include <LXQt/PowerManager>
 #include <LXQt/ScreenSaver>
 
 namespace Ui {
@@ -46,10 +48,17 @@ public:
     explicit LeaveDialog(QWidget *parent = 0);
     ~LeaveDialog();
 
+protected:
+    virtual void resizeEvent(QResizeEvent* event) override;
+
 private:
     Ui::LeaveDialog *ui;
-    LxQt::Power *mPower;
-    LxQt::ScreenSaver *mScreensaver;
+    // LXQt::Power is used to know if the actions are doable, while
+    // LXQt::PowerManager is used to trigger the actions, while
+    // obeying the user option to ask or not for confirmation
+    LXQt::Power *mPower;
+    LXQt::PowerManager *mPowerManager;
+    LXQt::ScreenSaver *mScreensaver;
 };
 
 
