@@ -1,28 +1,47 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu">
+<TS version="2.1" language="hu">
 <context>
-    <name>LxQtModuleManager</name>
+    <name>LXQtModuleManager</name>
     <message>
-        <location filename="../src/lxqtmodman.cpp" line="289"/>
+        <location filename="../src/lxqtmodman.cpp" line="311"/>
         <source>Crash Report</source>
         <translation>Összeomlás</translation>
     </message>
     <message>
-        <location filename="../src/lxqtmodman.cpp" line="290"/>
+        <location filename="../src/lxqtmodman.cpp" line="312"/>
         <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
-        <translation>A &lt;b&gt;%1&lt;/b&gt; gyorsan többször összeomlott. Az autorestart a következő bejeltkezésig letiltva.</translation>
+        <translation>A &lt;b&gt;%1&lt;/b&gt; gyorsan többször összeomlott. Az autorestart a következő bejelentkezésig letiltva.</translation>
+    </message>
+</context>
+<context>
+    <name>SessionApplication</name>
+    <message>
+        <location filename="../src/main.cpp" line="62"/>
+        <source>Configuration file path.</source>
+        <translation>Konfigurációs fájl útvonal.</translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="62"/>
+        <location filename="../src/main.cpp" line="63"/>
+        <source>file</source>
+        <translation>fájl</translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="63"/>
+        <source>Window manager to use.</source>
+        <translation>Használandó ablakkezelő.</translation>
     </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
     <message>
-        <location filename="../src/wmselectdialog.cpp" line="62"/>
+        <location filename="../src/wmselectdialog.cpp" line="65"/>
         <source>Other ...</source>
         <translation>Más...</translation>
     </message>
     <message>
-        <location filename="../src/wmselectdialog.cpp" line="63"/>
+        <location filename="../src/wmselectdialog.cpp" line="66"/>
         <source>Choose your favorite one.</source>
         <translation>Válassz egy kedvencet.</translation>
     </message>
